mirror of
https://gitlab.com/libeigen/eigen.git
synced 2026-04-10 11:34:33 +08:00
Merged in deven-amd/eigen/HIP_fixes (pull request PR-518)
PR with HIP specific fixes (for the eigen nightly regression failures in HIP mode)
This commit is contained in:
@@ -186,21 +186,21 @@ struct TensorContractionKernel {
|
||||
/*ConjugateLhs*/ false, /*ConjugateRhs*/ false>
|
||||
GebpKernel;
|
||||
|
||||
EIGEN_DONT_INLINE
|
||||
EIGEN_DEVICE_FUNC EIGEN_DONT_INLINE
|
||||
static void packLhs(LhsScalar* lhsBlock,
|
||||
const typename LhsMapper::SubMapper& data_mapper,
|
||||
const StorageIndex depth, const StorageIndex rows) {
|
||||
LhsPacker()(lhsBlock, data_mapper, depth, rows, /*stride*/ 0, /*offset*/ 0);
|
||||
}
|
||||
|
||||
EIGEN_DONT_INLINE
|
||||
EIGEN_DEVICE_FUNC EIGEN_DONT_INLINE
|
||||
static void packRhs(RhsScalar* rhsBlock,
|
||||
const typename RhsMapper::SubMapper& data_mapper,
|
||||
const StorageIndex depth, const StorageIndex cols) {
|
||||
RhsPacker()(rhsBlock, data_mapper, depth, cols);
|
||||
}
|
||||
|
||||
EIGEN_DONT_INLINE
|
||||
EIGEN_DEVICE_FUNC EIGEN_DONT_INLINE
|
||||
static void invoke(const OutputMapper& output_mapper,
|
||||
const LhsScalar* lhsBlock, const RhsScalar* rhsBlock,
|
||||
const StorageIndex rows, const StorageIndex depth,
|
||||
|
||||
@@ -218,6 +218,7 @@ struct InnerMostDimReducer<Self, Op, false, true> {
|
||||
}
|
||||
};
|
||||
|
||||
#if !defined(EIGEN_HIPCC)
|
||||
template <typename Self, typename Op>
|
||||
struct InnerMostDimReducer<Self, Op, true, true> {
|
||||
static EIGEN_DEVICE_FUNC EIGEN_STRONG_INLINE typename Self::CoeffReturnType
|
||||
@@ -257,7 +258,8 @@ struct InnerMostDimReducer<Self, Op, true, true> {
|
||||
}
|
||||
}
|
||||
};
|
||||
|
||||
#endif
|
||||
|
||||
template <int DimIndex, typename Self, typename Op, bool vectorizable = (Self::InputPacketAccess && Self::ReducerTraits::PacketAccess)>
|
||||
struct InnerMostDimPreserver {
|
||||
static EIGEN_DEVICE_FUNC EIGEN_STRONG_INLINE void reduce(const Self&, typename Self::Index, Op&, typename Self::PacketReturnType*) {
|
||||
|
||||
@@ -292,7 +292,7 @@ __global__ void FullReductionKernelHalfFloat(Reducer reducer, const Self input,
|
||||
}
|
||||
|
||||
template <typename Op>
|
||||
__global__ void ReductionCleanupKernelHalfFloat(Op& reducer, half* output, half2* scratch) {
|
||||
__global__ void ReductionCleanupKernelHalfFloat(Op reducer, half* output, half2* scratch) {
|
||||
eigen_assert(threadIdx.x == 1);
|
||||
half tmp = __low2half(*scratch);
|
||||
reducer.reduce(__high2half(*scratch), &tmp);
|
||||
|
||||
Reference in New Issue
Block a user